==> plover-stenobee-0.3.21.11.tar.gz: plover-stenobee-0.3.21.11/README.md <==
# StenoBee
>

>
Plover plugin for Spelling Based Stenography
>
Created by Tink & Emily & Kaoffie
>
With lots of help from, Jen and paulfioravanti :)
>

>
![StenoBee_larger](https://github.com/Tink-Bell/StenoBee/assets/143440063/d2bb970e-0163-400d-a901-0e479134b88e)
>

>
![ezgif-2-9a548ef0d5](https://github.com/Tink-Bell/StenoBee/assets/143440063/1bc790b8-b83d-4e1a-a4f7-52ff6f215e7b)
>

>

>
StenoBee, is a spelling based, orderless Steno theory for Plover.
>

>
![Plover_trans](https://github.com/Tink-Bell/StenoBee/assets/143440063/a63cce07-d8e1-4d6b-bf80-89ff05a1cd79)
>

>
Some key points about Stenobee
>
1) Originally made to avoid having issues with dialect differences in vowel sounds
>
2) Using custom Dictionary creation tools (provided at the very bottom), you can make the dictionary based solely on your own lexicon.
>
3) The default dictionary is made using a raw text file of 445k words (13k unique words), from myself over 3-4 years of my discord messages.
>

>
Some things that StenoBee is Good for
>
1) Can be easily customized using raw text or a ranked list.
>
2) It's great at encoding long phrases into single strokes(see example image above)
>

>

>
What is StenoBee is bad at.
>
1) Captioning, and court reporting work, since the orderless non phonetic nature of it actively makes transcription related work harder.
>
2) Small words are often made longer with suffixes if they are less common(see example image above)
>

>
![newlayout](https://github.com/Tink-Bell/StenoBee/assets/143440063/64458a5f-b230-46f6-a254-20d46189f56a)
>

>
![Number Mapping](https://github.com/Tink-Bell/StenoBee/assets/143440063/5d05e90d-5b49-402d-a0f1-a75bd1e15633)
>

>
![symb](https://github.com/Tink-Bell/StenoBee/assets/143440063/0d6782ad-ca47-4e3f-9bf3-9ffa05324232)
>

>
![STENOBEE_example](https://github.com/Tink-Bell/StenoBee/assets/143440063/d35d6ba6-cf48-4928-ad1b-6ac3a1719c6b)
>

>
![Screenshot from 2023-09-26 20-17-12](https://github.com/Tink-Bell/StenoBee/assets/143440063/c6d5c685-e5ca-4707-8218-0b65ffb7bcd2)
>

>
![Comparison](https://github.com/Tink-Bell/StenoBee/assets/143440063/ad3bdf0f-a322-47df-b9cf-7e5ad4d334ea)
>

>
IF you are here, and you are still interested.
>
You can also make the dictionary entirely based on what you want.
>
Using these tools, you can take either raw text, or a ranked list.
>
Then make a common words dictionary from it.
>

>
https://www.dropbox.com/scl/fi/0p09wxwk1vsha8tgkgi1q/Raw-text-to-List-Tools.zip?rlkey=dem74k15jicj63ir33hn0l51g&dl=0
>

>
https://www.dropbox.com/scl/fi/dfnrg4mn40s8mrj70d89y/List-to-Common-Json-Tools.zip?rlkey=zdx6ze8z8pg63ea26yqt9m7fg&dl=0
>

>
![examples](https://github.com/Tink-Bell/StenoBee/assets/143440063/a28a3695-86d0-4463-a5e6-3cf9dd6050b4)
>

==> plover-stenobee-0.3.21.13.tar.gz: plover-stenobee-0.3.21.13/README.md <==
# StenoBee
>

>
Plover plugin for Spelling Based Stenography
>
Created by Tink & Emily & Kaoffie
>
With lots of help from, Jen and paulfioravanti :)
>

>
![StenoBee_larger](https://github.com/Tink-Bell/StenoBee/assets/143440063/d2bb970e-0163-400d-a901-0e479134b88e)
>

>
![ezgif-2-9a548ef0d5](https://github.com/Tink-Bell/StenoBee/assets/143440063/1bc790b8-b83d-4e1a-a4f7-52ff6f215e7b)
>

>

>
StenoBee, is a spelling based, orderless Steno theory for Plover.
>

>
![Plover_trans](https://github.com/Tink-Bell/StenoBee/assets/143440063/a63cce07-d8e1-4d6b-bf80-89ff05a1cd79)
>

>
Some key points about Stenobee
>
1) Made to issues with dialect/phonetic differences pronunciation.
>
2) Comes with a default dictionary of 13k unique words from my own posts.
>
3) You can also make your dictionary from your own word list/raw text (using the tools at the bottom of the page)
>

>
What is StenoBee is bad at.
>
1) Captioning, and court reporting work, since the orderless non phonetic nature of it actively makes transcription related work harder.
>
2) Ambiguity with some shorter words, some memorization may be needed.
>

>
Some things that StenoBee is Good for
>
1) Can be easily customized using tools provided at the very bottom.
>
2) It's great at encoding long words and phrases into single strokes.
>

>

>
![newlayout](https://github.com/Tink-Bell/StenoBee/assets/143440063/64458a5f-b230-46f6-a254-20d46189f56a)
>

>
![Number Mapping](https://github.com/Tink-Bell/StenoBee/assets/143440063/5d05e90d-5b49-402d-a0f1-a75bd1e15633)
>

>
![symb](https://github.com/Tink-Bell/StenoBee/assets/143440063/0d6782ad-ca47-4e3f-9bf3-9ffa05324232)
>

>
![STENOBEE_example](https://github.com/Tink-Bell/StenoBee/assets/143440063/d35d6ba6-cf48-4928-ad1b-6ac3a1719c6b)
>

>
![Screenshot from 2023-09-26 20-17-12](https://github.com/Tink-Bell/StenoBee/assets/143440063/c6d5c685-e5ca-4707-8218-0b65ffb7bcd2)
>

>
![Comparison](https://github.com/Tink-Bell/StenoBee/assets/143440063/ad3bdf0f-a322-47df-b9cf-7e5ad4d334ea)
>

>
IF you are here, and you are still interested.
>
You can also make the dictionary entirely based on what you want.
>
Using these tools, you can take either raw text, or a ranked list.
>
Then make a common words dictionary from it.
>

>
Tools to filter and clean raw text, and turn it into 3 lists for easier handling.
>
https://www.dropbox.com/scl/fi/0p09wxwk1vsha8tgkgi1q/Raw-text-to-List-Tools.zip?rlkey=dem74k15jicj63ir33hn0l51g&dl=0
>

>
Tools to take your tex, and convert it into the dictionary file, replacing the "common" dictionary file.
>
https://www.dropbox.com/scl/fi/dfnrg4mn40s8mrj70d89y/List-to-Common-Json-Tools.zip?rlkey=zdx6ze8z8pg63ea26yqt9m7fg&dl=0
>

>
![examples](https://github.com/Tink-Bell/StenoBee/assets/143440063/a28a3695-86d0-4463-a5e6-3cf9dd6050b4)
>
